Module error

Module error 

Structs

CommandOutputError
A simple error type that wraps a string message Used for command output errors where we want to capture and display the output

Enums

CheckError
ConfigError
MQError
MainError
MergeError
RevisionError
VCSError
VCSOperationError
WorkDirError