Module error
selfci
0.4.0
Module error
Module Items
Structs
Enums
In crate selfci
selfci
Module
error
Structs

Command
Output
Error
A simple error type that wraps a string message Used for command output errors where we want to capture and display the output
Enums

Check
Error
Config
Error
MQError
Main
Error
Merge
Error
Revision
Error
VCSError
VCSOperation
Error
Work
DirError